==> GGF4.0.zip: GGF/GGFSetup.php <==
<?PHP
/**
 * Settings for Contacts application
 * 
 * @todo 
 * @package GGF
 * @version 4.0
 * @since 1.0
 * @author Gerald Zincke, Austria
 * @copyright 2005, 2011 Gerald Zincke
 */
ini_set("session.use_trans_sid", 0); 	// Do not add PHP Session ID automatically to relative links anhngen (this does not work for frames)
ini_set("session.use_cookies", 0);		// do not use local cookies
//ini_set("session.save_path","/home/vhosts/contacts.freetzi.com/mySessions");	// on a shared server for security reasons it makes sense redirect your session data to your private data area
																				// you need to supply the absolute server path to one of your directories
ini_set("session.use_only_cookies", 0);	// allow submission of Session ID via URL



$traceLevel = 2;		// 0: no error logging, 1: errors, 2: information
$largeListThreshold = 50; // if a rowset is larger than this, the browserwindow will show scroll buttons to allow a page-wise stepping through the row-set
                         // in a meaningful configuration this should always be bigger than $smallListPageSize
$smallListPageSize = 17; // this number is used by GGFControlSortDialog for the height of its listboxes
                         // and for GGFControlBrowserWindow for the initial page size (page-wise scrolling; more than $largeListTreshold lines to display)
                         // and if cookies are not supported
			 		     // for rowsets larger than $largeListTreshold this is the number of lines in a page. In a meaningful configuration this
                         // number of lines should fit on a 1024x768 screen, in a maxcimized browser window (without showing an elevator-scrollbar)
                         // be sure to leave room for button bars in the browser and large start- lines
$maxColumnSize = 132;    // maximum number of characters shown in a column of a GGFListArea
$HMItemHeight = 1.6;	 // height of menu menu item. Used fror 2nd level flyout menus in CSS and GGFControls

// application specific values
$appPath = "CTS/"; 				// relative path to application classes
$APPIconsPath = "CTSIcons/"; 	// relative path to application specific icons, shapes and graphics
$http_type = "http"; 			// may also be set to "https", if web server supports that
$historyTable = "GGFHistory"; 	// this is the name of a db-table will be used to write history (see GGFDatabase)
$dbhost = "localhost"; 			// See GGFDatabase. May be of the form www.server.domain:port
$dbuser = "root"; 				// See GGFDatabase, you should change this for production
$dbpw = ""; 					// See GGFDatabase, you should change this for production
$dbname = "Contacts"; 			// See GGFDatabase
$appname ="Contacts"; 			// application name, used in window title etc.
$appversion = "1.0"; 			// application version, used in GGFAboutDialog
$mainwindow = "CTSMainwindow.php";
$goodbyefile = "GGFGoodbye.php";
$invalidContextFile = "GGFInvalidContext.php";
$webmasterMail = "info@ReinHTML.eu"; // this is used for feedback mails in the system tray

// application specific variables
$accountlimit = 250; 
$maxOnlineFiles = 100;
$googleAnalyticsCode ='
';
$smtp = "email.aon.at"; 		// smtp server to send e-mails

?>

==> GGF4.1.zip: GGF/GGFSetup.php <==
<?PHP
/**
 * Settings for Contacts application
 * 
 * @todo 
 * @package GGF
 * @version 4.1
 * @since 1.0
 * @author Gerald Zincke, Austria
 * @copyright 2005, 2011 Gerald Zincke
 */
ini_set("expose_php",0);	// for security reasonss do not tell the world we are using php
ini_set("session.use_trans_sid", 0); 	// Do not add PHP Session ID automatically to relative links anhngen (this does not work for frames)
ini_set("session.use_cookies", 0);		// do not use local cookies
//ini_set("session.save_path","/home/vhosts/contacts.freetzi.com/mySessions");	// on a shared server for security reasons it makes sense redirect your session data to your private data area
																				// you need to supply the absolute server path to one of your directories
ini_set("session.use_only_cookies", 0);	// allow submission of Session ID via URL



$traceLevel = 2;		// 0: no error logging, 1: errors, 2: information
$largeListThreshold = 50; // if a rowset is larger than this, the browserwindow will show scroll buttons to allow a page-wise stepping through the row-set
                         // in a meaningful configuration this should always be bigger than $smallListPageSize
$smallListPageSize = 17; // this number is used by GGFControlSortDialog for the height of its listboxes
                         // and for GGFControlBrowserWindow for the initial page size (page-wise scrolling; more than $largeListTreshold lines to display)
                         // and if cookies are not supported
			 		     // for rowsets larger than $largeListTreshold this is the number of lines in a page. In a meaningful configuration this
                         // number of lines should fit on a 1024x768 screen, in a maxcimized browser window (without showing an elevator-scrollbar)
                         // be sure to leave room for button bars in the browser and large start- lines
$maxColumnSize = 132;    // maximum number of characters shown in a column of a GGFListArea
$HMItemHeight = 1.6;	 // height of menu menu item. Used fror 2nd level flyout menus in CSS and GGFControls

// application specific values
$appPath = "CTS/"; 				// relative path to application classes
$APPIconsPath = "CTSIcons/"; 	// relative path to application specific icons, shapes and graphics
$http_type = "http"; 			// may also be set to "https", if web server supports that
$historyTable = "GGFHistory"; 	// this is the name of a db-table will be used to write history (see GGFDatabase)
$dbhost = "localhost"; 			// See GGFDatabase. May be of the form www.server.domain:port
$dbuser = "root"; 				// See GGFDatabase, you should change this for production
$dbpw = ""; 					// See GGFDatabase, you should change this for production
$dbname = "Contacts"; 			// See GGFDatabase
$appname ="Contacts"; 			// application name, used in window title etc.
$appversion = "1.0"; 			// application version, used in GGFAboutDialog
$mainwindow = "CTSMainwindow.php";
$goodbyefile = "GGFGoodbye.php";
$invalidContextFile = "GGFInvalidContext.php";
$webmasterMail = "info@myserver.com"; // this is used for feedback mails in the system tray

// application specific variables
$accountlimit = 250; 
$maxOnlineFiles = 100;
$googleAnalyticsCode ='
';
$smtp = "email.myserver.com"; 		// smtp server to send e-mails

?>
